class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'


class COMMANDS_MESSAGES:
    @classmethod
    def add_color(cls, command, file_=False):
        if not file_:
            _colored_message = f'{bcolors.BOLD}{bcolors.OKGREEN}[INFO]{bcolors.ENDC} running{bcolors.OKBLUE} {command} {bcolors.ENDC}'
        else:
            _colored_message = f'{bcolors.BOLD}{bcolors.OKGREEN}[INFO]{bcolors.ENDC} running {bcolors.BOLD}{bcolors.OKCYAN} CREATING FILE {bcolors.ENDC} {bcolors.OKBLUE}{command} {bcolors.ENDC}'
        return _colored_message

ERROR_MESSAGE = f'{bcolors.FAIL}{bcolors.BOLD}[ERROR] msg {bcolors.ENDC}'



BABELRC_CONTENT = u'''{
    "presets": [
        "@babel/preset-env", "@babel/preset-react"
    ]
}'''

WEBPACK_CONFIG_JS_CONTENT = u'''module.exports = {
    watch: true,
    module: {
        rules: [
            {
                test: /\.js$/,
                exclude: /node_modules/,
                use: {
                    loader: "babel-loader"
                }
            }
        ]
    }
}'''

INDEX_HTML_DJANGO_CONTENT = u'''<!DOCTYPE html>
<html>
    <head>
      <meta charset="utf-8">
      <meta name="viewport" content="width=device-width, initial-scale=1">
      <title>Pycra Application</title>
    </head>
<body>
    <div id="app">
        <!-- React will load here -->
    </div>
</body>
    <!-- DJANGO_PLACEHOLDER -->
    {% load static %}
    <script src="{% static '{self.app_name}/js/main.js' %}"></script>
</html>'''

INDEX_HTML_FLASK_CONTENT = u'''<!DOCTYPE html>
<html>
    <head>
      <meta charset="utf-8">
      <meta name="viewport" content="width=device-width, initial-scale=1">
      <title>Pycra Application</title>
    </head>
<body>
    <div id="app">
        <!-- React will load here -->
    </div>
</body>
    <script src="{{ url_for('static', filename='js/main.js') }}"></script>
</html>'''


APP_JS_CONTENT = '''import React, { Component } from "react";
import { render } from "react-dom";

class App extends Component {
constructor(props) {
    super(props);
    this.state = {};
  }
  render() {
    return (
      <div>
        <h1 style={{textAlign: 'center'}}>Hello World</h1>
      </div>
    );
  }
}
export default App;

const container = document.getElementById("app");
render(<App />, container);'''

INDEX_JS_CONTENT = u'''import App from "./components/App";'''





from PyCRA import PycraDjango, PycraFlask
from PyCRA.parser import create_parser
from PyCRA.messages import ERROR_MESSAGE

from PyCRA._checker import _check

import sys


parser = create_parser()
args = parser.parse_args()


_check()

if args.mode:
    if args.mode == 'django':
        if args.app_name:
            try:
                PycraDjango(app_name=args.app_name).execute()
            except Exception as e:
                print(ERROR_MESSAGE.replace('msg', str(e)))
        else:
            print(ERROR_MESSAGE.replace('msg', 'app name is required'))
            sys.exit(0)

    elif args.mode == 'flask':
        if args.app_dir:
            try:
                PycraFlask(app_dir=args.app_dir).execute()
            except Exception as e:
                print(ERROR_MESSAGE.replace('msg', str(e)))
        else:
            print(ERROR_MESSAGE.replace('msg', 'app dir is required'))
            sys.exit(0)
else:
    _mode = str(input('Enter your application mode [django/flask] :- '))
    if _mode == 'django':
        _app_name = str(input('Enter your django app name :- '))
        if _app_name:
            PycraDjango(app_name=_app_name).execute()
        else:
            print(ERROR_MESSAGE.replace('msg', 'app name is required'))
            sys.exit(0)
    elif _mode == 'flask':
        _app_dir = str(input('Enter your app dir :- '))
        if _app_dir:
            PycraFlask(app_dir=_app_dir).execute()
        else:
            print(ERROR_MESSAGE.replace('msg', 'app dir is required'))
            sys.exit(0)
    else:
        print(ERROR_MESSAGE.replace('msg', 'Ivalid set of choices'))
        sys.exit(0)




import os
import sys

from PyCRA.messages import ERROR_MESSAGE

def _check_path():
    _path_dirs = None

    if sys.platform == 'win32':
        _path_dirs = os.environ['PATH'].split(';')
    elif sys.platform == 'linux':
        _path_dirs = os.environ['PATH'].split(':')

    _npm = False
    _node = False

    if _path_dirs:
        for d in _path_dirs:
            if os.path.isfile(d+'/npm'):
                _npm = True

            if os.path.isfile(d+'/node'):
                _node = True

        if _node and _npm:
            return True
        else:
            return False


def _check():

    if not _check_path():
        print(ERROR_MESSAGE.replace('msg', 'please, make sure that npm and nodejs are installed'))
        sys.exit(0)




from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

long_desc = (here / 'README.md').read_text(encoding='utf-8')


setup(
        name='py_cra',
        version='0.0.6',
        description='Python tool to create an react web app for django or flask backend',
        long_description=long_desc,
        long_description_content_type='text/markdown',
        url='https://github.com/Moaz-Mohammed-Elesawey/py-cra',
        author='Moaz Mohammed El-Esawey',
        author_email='mohammedmiaz3141@gmail.com',
        classifiers=[
            'Development Status :: 5 - Production/Stable',
            'License :: OSI Approved :: MIT License',
            'Programming Language :: Python :: 3',
        ],
        keywords='react, frontend, python, pycra',
        package_dir={'': 'src'},
        packages=find_packages(where='src'),
        python_requires='>=3.6, <4',
        project_urls={
        'Source': 'https://github.com/Moaz-Mohammed-Elesawey/py-cra',
    },
)



import argparse

def create_parser():

    parser = argparse.ArgumentParser()
    parser.add_argument('--mode', type=str, help="django or flask mode")
    parser.add_argument('--app_name', type=str, help='app name if django mode')
    parser.add_argument('--app_dir', type=str, help='app dir if flask mode')
    parser.add_argument('--version', type=str, help='version of the package')

    return parser
